@@ -11,9 +11,10 @@
 
 #include <QSortFilterProxyModel>
 
-#include "declarativemanager.h"
 #include "devicesmodel.h"
 
+class DeclarativeManager;
+
 class DeclarativeDevicesModel : public QSortFilterProxyModel
 {
     Q_OBJECT
